#include <windows.h>
#include <windowsx.h>
#include <tchar.h>
#include "printbmp.rc"

//////////////////////////////////////////////////////////////
HDC GetPrinterDC (HWND hwnd)
{
    PRINTDLG pd;
    memset(&pd,0,sizeof(pd));

    pd.lStructSize = sizeof(pd);
    pd.hwndOwner   = hwnd;
    pd.Flags = PD_RETURNDC;

    if (PrintDlg(&pd))
        return pd.hDC;

    return 0;
}

//////////////////////////////////////////////////////////////

void PageGDICalls(HDC hdc, HWND hwnd, int width, int height)
{
  HDC hDlgDC;
  HBITMAP hBitmap;
  int cx, cy;
  RECT rect;

  hDlgDC = GetWindowDC(hwnd);
  GetWindowRect(hwnd,&rect);
  
  UpdateWindow(hwnd);       //do this so the window is painted before printing!

  cx = rect.right - rect.left;
  cy = rect.bottom - rect.top;

  StretchBlt(hdc,0,0,width,height,hDlgDC,0,0,cx,cy,SRCCOPY);
}

//////////////////////////////////////////////////////////////

bool PrintSomePages(HWND hwnd)
{
  static DOCINFO di = {sizeof(DOCINFO), NULL, NULL};
  bool bError = false;
  HDC hdcPrn;
  int xPage, yPage;
  
  if (NULL == (hdcPrn = GetPrinterDC(hwnd)))
    return true;

  xPage = GetDeviceCaps (hdcPrn, HORZRES) ;
  yPage = GetDeviceCaps (hdcPrn, VERTRES) ;

  if (StartDoc (hdcPrn, &di) > 0)
  {
    if (StartPage (hdcPrn) > 0)
    {
      PageGDICalls (hdcPrn, hwnd, xPage, yPage) ;

      if (EndPage (hdcPrn) > 0)
        EndDoc (hdcPrn) ;
      else
        bError = true ;
    }
  }
  else
    bError = true ;

  return bError ;
}

//////////////////////////////////////////////////////////////


void Dlg_OnCommand (HWND hwnd, int id, HWND hwndCtl, 
   UINT codeNotify) {
   

   switch (id) {
      case IDCANCEL:
         EndDialog(hwnd, id);
         break;

      case IDC_PRINT:
         PrintSomePages(hwnd); 
         break;
   }
}


///////////////////////////////////////////////////////////////


bool CALLBACK Dlg_Proc (HWND hDlg, UINT uMsg, 
   WPARAM wParam, LPARAM lParam) {
   
   bool fProcessed = true;

   switch (uMsg) {
      HANDLE_MSG(hDlg, WM_COMMAND, Dlg_OnCommand);

      default:
         fProcessed = false;
         break;
   }
   return(fProcessed);
}


///////////////////////////////////////////////////////////////


int WINAPI wWinMain (HINSTANCE hinstExe,
   HINSTANCE hinstPrev, LPWSTR lpszCmdLine, int nCmdShow) {

   DialogBox(hinstExe, MAKEINTRESOURCE(IDD_PRINTBMPDIALOG), 
             NULL, (DLGPROC)Dlg_Proc);

   return(0);
}


///////////////////////// End Of File /////////////////////////
